# October 31, 2024 - Version 1.6.0

Please update PrismStudio via

```python
pip install prismstudio --upgrade
```

or

```python
pip install prismstudio==1.6.0
```


If you prefer to use Anaconda, please install PrismStudio using command below

```bash
conda config --add channels conda-forge
conda install -c prism39 prismstudio
```


---

## Change Log
- Added save_timerange_sql_as_universe: saves SQL query results as a universe based on specified start and end date columns, with support for multiple ID columns.
- Added save_timeseries_sql_as_universe: saves time-series SQL query results as a universe using a date column, with support for multiple ID columns.
- Fixed bug that resulting object from prismstudio.map() is not operable.
- Security Master Baseids: listingid, securityid, companyid has changed.

